#!/bin/sh

starttime=201908311800
ctime=201908312100
endtime=201909010000

year=`echo $starttime | cut -c1-4`
basin=atlantic
dropdir=/lfs3/projects/hfip-hda/OBSDATA/${year}/public/data/dropsonde/${basin}
advdir=/public/data/nhc/advisories
mkdir WORK
cp wud.x WORK/
cp get_shear.x WORK/

cd WORK
mydir=`pwd`

#Get Dropsondes
cd $dropdir
for i in `ls $year*`
do
   droptime=`echo $i | cut -c1-12`
   if [ $droptime -ge $starttime -a $droptime -le $endtime ]
   then
      cp $i ${mydir}/${i}.d
   fi
done

#Get Advisories
cd $advdir
for i in `ls $year*`
do
   advtime=`echo $i | cut -c1-12`
   if [ $advtime -ge $starttime -a $advtime -le $endtime ]
   then
      cp $i ${mydir}/${i}.adv
   fi
done

cd $mydir
#Process Dropsondes

echo "DROPS" > obslist

for i in `ls *.d`
do
   echo $i >> obslist
   dropnum=`expr $dropnum + 1`
   #rm carriage control characters and put drops in HRD spline analysis format
   echo "000" > ${i}.txt
   sed '/^$/d' $i > dfile
   strings dfile >> ${i}.txt
   echo "=" >> ${i}.txt
   rm dfile
   ./wud.x ${i}.txt
   cat fort.15 >> DROP_HSA.dat
   rm fort*
   rm $i $i.txt
done

sdate=`echo $starttime | cut -c1-8`
stime=`echo $starttime | cut -c9-12`
edate=`echo $endtime | cut -c1-8`
etime=`echo $endtime | cut -c9-12`

#Pick advisory closest to center time

mintime=2400
echo "ADVISORIES" >> obslist

for i in `ls *adv`
do
   echo $i >> obslist
   advdate=`echo $i | cut -c1-8`
   advtime=`echo $i | cut -c9-12`
   if [ $sdate -eq $advdate ]
   then
       tdiff1=`expr $advtime - $stime`
   else
       tdiff1=`expr $advtime + 2400 - $stime`
   fi
 
   if [ $edate -eq $advdate ]
   then
      tdiff2=`expr $etime - $advtime`
   else
      tdiff2=`expr $etime + 2400 - $advtime`
   fi

   if [ $tdiff2 -ge $tdiff1 ]
   then
      tdiff=`expr $tdiff2 - $tdiff1`
   else
      tdiff=`expr $tdiff1 - $tdiff2`
   fi

   if [ $tdiff -lt $mintime ]
   then
      mintime=$tdiff
      advuse=$i
   fi
done

echo "ADVISORY USED "$advuse >> obslist

#Get storm position and motion from advisory
   
advtime=`grep WAS $advuse | cut -d'/' -f2 | cut -c1-4`
clat=`grep WAS $advuse | cut -d'/' -f2 | cut -d' ' -f6`

shift=0

if [ -z $clat ]
then
   clat=`grep WAS $advuse | cut -d'/' -f2 | cut -d' ' -f7`
   shift=1
   lat=`echo $clat | cut -c1-3`
   hem=`echo $clat | cut -c4`
else
   lat=`echo $clat | cut -c1-4`
   hem=`echo $clat | cut -c5`
fi

if [ $hem == "S" ]
then
   clat=-${lat}
else
   clat=${lat}
fi

shift=`expr $shift + 7`
clon=`grep WAS $advuse | cut -d'/' -f2 | cut -d' ' -f${shift}`

if [ -z $clon ]
then
   shift=`expr $shift + 1`
   clon=`grep WAS $advuse | cut -d'/' -f2 | cut -d' ' -f${shift}`
   lon=`echo $clon | cut -c1-4`
   hem=`echo $clon | cut -c5`
else
   lon=`echo $clon | cut -c1-5`
   hem=`echo $clon | cut -c6`
fi

if [ $hem == "W" ]
then
   clon=-${lon}
else
   clon=${lon}
fi

sdir=`grep MOVEMENT $advuse | cut -d' ' -f7`

shift=0

if [ -z $sdir ]
then
   sdir=`grep MOVEMENT $advuse | cut -d' ' -f8`
   shift=1

   if [ -z $sdir ]
   then
      sdir=`grep MOVEMENT $advuse | cut -d' ' -f9`
      shift=2
   fi
fi

shift=`expr $shift + 10`

sspd=`grep MOVEMENT $advuse | cut -d' ' -f${shift}`

if [ -z $sspd ]
then
   shift=`expr $shift + 1`
   sspd=`grep MOVEMENT $advuse | cut -d' ' -f${shift}`
   if [ -z $sspd ]
   then
      shift=`expr $shift + 1`
      sspd=`grep MOVEMENT $advuse | cut -d' ' -f${shift}`
      if [ -z $sspd ]
      then
         shift=`expr $shift + 1`
         sspd=`grep MOVEMENT $advuse | cut -d' ' -f${shift}`
      fi
   fi
fi


echo "speed "$sspd" dir "$sdir" clat "$clat" clon "$clon" advtime "$advtime
#./get_shear.x $sspd $sdir $clat $clon $advtime
                                                                                    
